@@ -139,6 +139,28 @@ type CheClusterSpecServer struct {
 	// The default value is `true`.
 	// +optional
 	UseInternalClusterSVCNames bool `json:"useInternalClusterSVCNames"`
+	// Overrides the container image used in the dashboard deployment.
+	// This includes the image tag. Omit it or leave it empty to use the default container image provided by the Operator.
+	// +optional
+	DashboardImage string `json:"dashboardImage,omitempty"`
+	// Overrides the image pull policy used in the dashboard deployment.
+	// Default value is `Always` for `nightly` or `latest` images, and `IfNotPresent` in other cases.
+	// +optional
+	DashboardImagePullPolicy string `json:"dashboardImagePullPolicy,omitempty"`
+	// Overrides the memory limit used in the dashboard deployment. Defaults to 256Mi.
+	// +optional
+	DashboardMemoryLimit string `json:"dashboardMemoryLimit,omitempty"`
+	// Overrides the memory request used in the dashboard deployment. Defaults to 16Mi.
+	// +optional
+	DashboardMemoryRequest string `json:"dashboardMemoryRequest,omitempty"`
+	// Overrides the CPU limit used in the dashboard deployment.
+	// In cores. (500m = .5 cores). Default to 500m.
+	// +optional
+	DashboardCpuLimit string `json:"dashboardCpuLimit,omitempty"`
+	// Overrides the CPU request used in the dashboard deployment.
+	// In cores. (500m = .5 cores). Default to 100m.
+	// +optional
+	DashboardCpuRequest string `json:"dashboardCpuRequest,omitempty"`
 	// Public URL of the devfile registry, that serves sample, ready-to-use devfiles.
 	// Set this ONLY when a use of an external devfile registry is needed. See the `externalDevfileRegistry` field.
 	// By default, this will be automatically calculated by the Operator.
@@ -339,7 +361,7 @@ type CheClusterSpecAuth struct {
 	// If the value is true, then a new OpenShift OAuth user will be created for the HTPasswd identity provider.
 	// If the value is false and the user has already been created, then it will be removed.
 	// If value is an empty, then do nothing.
-	// The user's credentials are stored in the `openshift-oauth-user-credentials` secret by Operator.
+	// The user's credentials are stored in the `openshift-oauth-user-credentials` secret in 'openshift-config' namespace by Operator.
 	// Note that this solution is Openshift 4 platform-specific.
 	InitialOpenShiftOAuthUser *bool `json:"initialOpenShiftOAuthUser,omitempty"`
 	// Instructs the Operator on whether or not to deploy a dedicated Identity Provider (Keycloak or RH SSO instance).
@@ -557,16 +579,19 @@ type CheClusterSpecDevWorkspace struct {
 	// +operator-sdk:gen-csv:customresourcedefinitions.specDescriptors.displayName="Enable Dev Workspace operator"
 	// +operator-sdk:gen-csv:customresourcedefinitions.specDescriptors.x-descriptors="urn:alm:descriptor:com.tectonic.ui:booleanSwitch"
 	Enable bool `json:"enable"`
+	// Overrides the container image used in the DevWorkspace controller deployment.
+	// This includes the image tag. Omit it or leave it empty to use the default container image provided by the Operator.
+	// +optional
+	ControllerImage string `json:"controllerImage,omitempty"`
 }
 
 // CheClusterStatus defines the observed state of Che installation
 type CheClusterStatus struct {
-	// OpenShift OAuth secret that contains user credentials for HTPasswd identity provider.
+	// OpenShift OAuth secret in `openshift-config` namespace that contains user credentials for HTPasswd identity provider.
 	// +operator-sdk:gen-csv:customresourcedefinitions.statusDescriptors=true
-	// +operator-sdk:gen-csv:customresourcedefinitions.statusDescriptors.displayName="OpenShift OAuth secret that contains user credentials for HTPasswd identity provider."
+	// +operator-sdk:gen-csv:customresourcedefinitions.statusDescriptors.displayName="OpenShift OAuth secret in `openshift-config` namespace that contains user credentials for HTPasswd identity provider."
 	// +operator-sdk:gen-csv:customresourcedefinitions.statusDescriptors.x-descriptors="urn:alm:descriptor:text"
-	OpenShiftOAuthUserCredentialsSecret string `json:"openShiftOAuthUserCredentialsSecret"`
-	// Indicates that a PostgreSQL instance has been correctly provisioned or not.
+	OpenShiftOAuthUserCredentialsSecret string `json:"openShiftOAuthUserCredentialsSecret,omitempty"`
 	// Indicates that a PostgreSQL instance has been correctly provisioned or not.
 	// +optional
 	DbProvisoned bool `json:"dbProvisioned"`
