@@ -13,7 +13,6 @@ package che
 
 import (
 	"context"
-	"fmt"
 	"reflect"
 	"strconv"
 	"strings"
@@ -21,11 +20,12 @@ import (
 
 	orgv1 "github.com/eclipse-che/che-operator/pkg/apis/org/v1"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
+	"github.com/eclipse-che/che-operator/pkg/deploy/dashboard"
 	devworkspace "github.com/eclipse-che/che-operator/pkg/deploy/dev-workspace"
-	devfile_registry "github.com/eclipse-che/che-operator/pkg/deploy/devfile-registry"
+	"github.com/eclipse-che/che-operator/pkg/deploy/devfileregistry"
 	"github.com/eclipse-che/che-operator/pkg/deploy/gateway"
 	identity_provider "github.com/eclipse-che/che-operator/pkg/deploy/identity-provider"
-	plugin_registry "github.com/eclipse-che/che-operator/pkg/deploy/plugin-registry"
+	"github.com/eclipse-che/che-operator/pkg/deploy/pluginregistry"
 	"github.com/eclipse-che/che-operator/pkg/deploy/postgres"
 	"github.com/eclipse-che/che-operator/pkg/deploy/server"
 	"github.com/eclipse-che/che-operator/pkg/util"
@@ -136,10 +136,8 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 		if err := corev1.AddToScheme(mgr.GetScheme()); err != nil {
 			logrus.Errorf("Failed to add OpenShift Core to scheme: %s", err)
 		}
-		if util.HasAPIResourceName(deploy.ConsoleLinksResourceName) {
-			if err := consolev1.AddToScheme(mgr.GetScheme()); err != nil {
-				logrus.Errorf("Failed to add OpenShift ConsoleLink to scheme: %s", err)
-			}
+		if err := consolev1.AddToScheme(mgr.GetScheme()); err != nil {
+			logrus.Errorf("Failed to add OpenShift ConsoleLink to scheme: %s", err)
 		}
 	}
 
@@ -277,8 +275,6 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 var (
 	_ reconcile.Reconciler = &ReconcileChe{}
 
-	cheWorkspacesClusterPermissionsFinalizerName = "cheWorkspaces.clusterpermissions.finalizers.che.eclipse.org"
-
 	// CheServiceAccountName - service account name for che-server.
 	CheServiceAccountName = "che"
 )
@@ -343,9 +339,8 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 	}
 
 	deployContext := &deploy.DeployContext{
-		ClusterAPI:      clusterAPI,
-		CheCluster:      instance,
-		InternalService: deploy.InternalService{},
+		ClusterAPI: clusterAPI,
+		CheCluster: instance,
 	}
 
 	// Reconcile finalizers before CR is deleted
@@ -408,15 +403,16 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 		return reconcile.Result{}, nil
 	}
 
+	// Update status if OpenShift initial user is deleted (in the previous step)
 	if instance.Spec.Auth.InitialOpenShiftOAuthUser == nil && instance.Status.OpenShiftOAuthUserCredentialsSecret != "" {
-		secret, err := deploy.GetSecret(deployContext, openShiftOAuthUserCredentialsSecret, instance.Namespace)
-		if secret == nil {
-			if err == nil {
-				instance.Status.OpenShiftOAuthUserCredentialsSecret = ""
-				if err := r.UpdateCheCRStatus(instance, "openShiftOAuthUserCredentialsSecret", ""); err != nil {
-					return reconcile.Result{}, err
-				}
-			} else {
+		secret := &corev1.Secret{}
+		exists, err := getOpenShiftOAuthUserCredentialsSecret(deployContext, secret)
+		if err != nil {
+			// We should `Requeue` since we deal with cluster scope objects
+			return reconcile.Result{RequeueAfter: time.Second}, err
+		} else if !exists {
+			instance.Status.OpenShiftOAuthUserCredentialsSecret = ""
+			if err := r.UpdateCheCRStatus(instance, "openShiftOAuthUserCredentialsSecret", ""); err != nil {
 				return reconcile.Result{}, err
 			}
 		}
@@ -565,38 +561,6 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 		return reconcile.Result{RequeueAfter: 5 * time.Second}, nil
 	}
 
-	// If the devfile-registry ConfigMap exists, and we are not in airgapped mode, delete the ConfigMap
-	devfileRegistryConfigMap := &corev1.ConfigMap{}
-	err = r.client.Get(context.TODO(), types.NamespacedName{Namespace: instance.Namespace, Name: deploy.DevfileRegistryName}, devfileRegistryConfigMap)
-	if err != nil && !errors.IsNotFound(err) {
-		logrus.Errorf("Error getting devfile-registry ConfigMap: %v", err)
-		return reconcile.Result{}, err
-	}
-	if err == nil && instance.Spec.Server.ExternalDevfileRegistry {
-		logrus.Info("Found devfile-registry ConfigMap and while using an external devfile registry.  Deleting.")
-		if err = r.client.Delete(context.TODO(), devfileRegistryConfigMap); err != nil {
-			logrus.Errorf("Error deleting devfile-registry ConfigMap: %v", err)
-			return reconcile.Result{}, err
-		}
-		return reconcile.Result{Requeue: true}, nil
-	}
-
-	// If the plugin-registry ConfigMap exists, and we are not in airgapped mode, delete the ConfigMap
-	pluginRegistryConfigMap := &corev1.ConfigMap{}
-	err = r.client.Get(context.TODO(), types.NamespacedName{Namespace: instance.Namespace, Name: deploy.PluginRegistryName}, pluginRegistryConfigMap)
-	if err != nil && !errors.IsNotFound(err) {
-		logrus.Errorf("Error getting plugin-registry ConfigMap: %v", err)
-		return reconcile.Result{}, err
-	}
-	if err == nil && !instance.IsAirGapMode() {
-		logrus.Info("Found plugin-registry ConfigMap and not in airgap mode.  Deleting.")
-		if err = r.client.Delete(context.TODO(), pluginRegistryConfigMap); err != nil {
-			logrus.Errorf("Error deleting plugin-registry ConfigMap: %v", err)
-			return reconcile.Result{}, err
-		}
-		return reconcile.Result{Requeue: true}, nil
-	}
-
 	if err := r.SetStatusDetails(instance, request, "", "", ""); err != nil {
 		return reconcile.Result{}, err
 	}
@@ -604,63 +568,29 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 	// Create service account "che" for che-server component.
 	// "che" is the one which token is used to create workspace objects.
 	// Notice: Also we have on more "che-workspace" SA used by plugins like exec, terminal, metrics with limited privileges.
-	cheSA, err := deploy.SyncServiceAccountToCluster(deployContext, CheServiceAccountName)
-	if cheSA == nil {
-		logrus.Info("Waiting on service account 'che' to be created")
+	done, err = deploy.SyncServiceAccountToCluster(deployContext, CheServiceAccountName)
+	if !done {
 		if err != nil {
 			logrus.Error(err)
 		}
-		if !tests {
-			return reconcile.Result{RequeueAfter: time.Second}, err
-		}
+		return reconcile.Result{RequeueAfter: time.Second}, err
 	}
 
-	if !util.IsOAuthEnabled(instance) && !util.IsWorkspaceInSameNamespaceWithChe(instance) {
-		сheWorkspacesClusterRoleName := fmt.Sprintf(CheWorkspacesClusterRoleNameTemplate, instance.Namespace)
-		exists, err := deploy.Get(deployContext, types.NamespacedName{Name: сheWorkspacesClusterRoleName}, &rbac.ClusterRole{})
+	done, err = r.checkWorkspacePermissions(deployContext)
+	if !done {
 		if err != nil {
 			logrus.Error(err)
-			return reconcile.Result{RequeueAfter: time.Second}, err
-		}
-		if !exists {
-			policies := append(getCheWorkspacesNamespacePolicy(), getCheWorkspacesPolicy()...)
-			deniedRules, err := r.permissionChecker.GetNotPermittedPolicyRules(policies, "")
-			if err != nil {
-				logrus.Error(err)
-				return reconcile.Result{RequeueAfter: time.Second}, err
-			}
-			// fall back to the "narrower" workspace namespace strategy
-			if len(deniedRules) > 0 {
-				logrus.Warnf("Not enough permissions to start a workspace in dedicated namespace. Denied policies: %v", deniedRules)
-				logrus.Warnf("Fall back to '%s' namespace for workspaces.", instance.Namespace)
-				delete(instance.Spec.Server.CustomCheProperties, "CHE_INFRA_KUBERNETES_NAMESPACE_DEFAULT")
-				instance.Spec.Server.WorkspaceNamespaceDefault = instance.Namespace
-				err := r.UpdateCheCRSpec(instance, "Default namespace for workspaces", instance.Namespace)
-				if err != nil {
-					logrus.Error(err)
-					return reconcile.Result{RequeueAfter: time.Second * 1}, err
-				}
-			} else {
-				reconcileResult, err := r.delegateWorkspacePermissionsInTheDifferNamespaceThanChe(deployContext)
-				if err != nil {
-					logrus.Error(err)
-					return reconcile.Result{RequeueAfter: time.Second}, err
-				}
-				if reconcileResult.Requeue {
-					return reconcileResult, err
-				}
-			}
 		}
+		return reconcile.Result{}, err
 	}
 
-	if util.IsOAuthEnabled(instance) || util.IsWorkspaceInSameNamespaceWithChe(instance) {
-		reconcile, err := r.delegateWorkspacePermissionsInTheSameNamespaceWithChe(deployContext)
+	done, err = r.reconcileWorkspacePermissions(deployContext)
+	if !done {
 		if err != nil {
 			logrus.Error(err)
 		}
-		if reconcile.Requeue && !tests {
-			return reconcile, err
-		}
+		// reconcile after 1 seconds since we deal with cluster objects
+		return reconcile.Result{RequeueAfter: time.Second}, err
 	}
 
 	if len(instance.Spec.Server.CheClusterRoles) > 0 {
@@ -685,15 +615,12 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 	// Use a role binding instead of a cluster role binding to keep the additional access scoped to the workspace's namespace
 	workspaceClusterRole := instance.Spec.Server.CheWorkspaceClusterRole
 	if workspaceClusterRole != "" {
-		cheWSCustomRoleBinding, err := deploy.SyncRoleBindingToCluster(deployContext, "che-workspace-custom", "view", workspaceClusterRole, "ClusterRole")
-		if cheWSCustomRoleBinding == nil {
-			logrus.Info("Waiting on role binding 'che-workspace-custom' to be created")
+		done, err := deploy.SyncRoleBindingToCluster(deployContext, "che-workspace-custom", "view", workspaceClusterRole, "ClusterRole")
+		if !done {
 			if err != nil {
 				logrus.Error(err)
 			}
-			if !tests {
-				return reconcile.Result{RequeueAfter: time.Second}, err
-			}
+			return reconcile.Result{RequeueAfter: time.Second}, err
 		}
 	}
 
@@ -704,127 +631,34 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 	cheMultiUser := deploy.GetCheMultiUser(instance)
 
 	if cheMultiUser == "false" {
-		done, err := deploy.SyncPVCToCluster(deployContext, deploy.DefaultCheVolumeClaimName, "1Gi", cheFlavor)
-		if !tests {
-			if !done {
+		claimSize := util.GetValue(instance.Spec.Storage.PvcClaimSize, deploy.DefaultPvcClaimSize)
+		done, err := deploy.SyncPVCToCluster(deployContext, deploy.DefaultCheVolumeClaimName, claimSize, cheFlavor)
+		if !done {
+			if err != nil {
+				logrus.Error(err)
+			} else {
 				logrus.Infof("Waiting on pvc '%s' to be bound. Sometimes PVC can be bound only when the first consumer is created.", deploy.DefaultCheVolumeClaimName)
-				if err != nil {
-					logrus.Error(err)
-				}
-				return reconcile.Result{}, err
-			}
-		}
-
-		done, err = deploy.DeleteNamespacedObject(deployContext, deploy.DefaultPostgresVolumeClaimName, &corev1.PersistentVolumeClaim{})
-		if !tests {
-			if !done {
-				if err != nil {
-					logrus.Error(err)
-				}
-				return reconcile.Result{}, err
 			}
+			return reconcile.Result{}, err
 		}
 	} else {
 		done, err := deploy.DeleteNamespacedObject(deployContext, deploy.DefaultCheVolumeClaimName, &corev1.PersistentVolumeClaim{})
-		if !tests {
-			if !done {
-				if err != nil {
-					logrus.Error(err)
-				}
-				return reconcile.Result{}, err
+		if !done {
+			if err != nil {
+				logrus.Error(err)
 			}
+			return reconcile.Result{}, err
 		}
 	}
 
-	// Create Postgres resources and provisioning unless an external DB is used
-	externalDB := instance.Spec.Database.ExternalDb
-	if !externalDB {
-		if cheMultiUser == "false" {
-			done, err := deploy.Delete(deployContext, types.NamespacedName{Name: deploy.PostgresName, Namespace: instance.Namespace}, &appsv1.Deployment{})
-			if !tests {
-				if !done {
-					if err != nil {
-						logrus.Error(err)
-					}
-					return reconcile.Result{}, err
-				}
-			}
-		} else {
-			// Create a new postgres service
-			serviceStatus := deploy.SyncServiceToCluster(deployContext, deploy.PostgresName, []string{deploy.PostgresName}, []int32{5432}, deploy.PostgresName)
-			if !tests {
-				if !serviceStatus.Continue {
-					logrus.Info("Waiting on service 'postgres' to be ready")
-					if serviceStatus.Err != nil {
-						logrus.Error(serviceStatus.Err)
-					}
-
-					return reconcile.Result{Requeue: serviceStatus.Requeue}, serviceStatus.Err
-				}
-			}
-
-			// Create a new Postgres PVC object
-			done, err := deploy.SyncPVCToCluster(deployContext, deploy.DefaultPostgresVolumeClaimName, "1Gi", deploy.PostgresName)
-			if !tests {
-				if !done {
-					logrus.Infof("Waiting on pvc '%s' to be bound. Sometimes PVC can be bound only when the first consumer is created.", deploy.DefaultPostgresVolumeClaimName)
-					if err != nil {
-						logrus.Error(err)
-					}
-
-					return reconcile.Result{}, err
-				}
-			}
-
-			// Create a new Postgres deployment
-			provisioned, err := postgres.SyncPostgresDeploymentToCluster(deployContext)
-			if !tests {
-				if !provisioned {
-					logrus.Infof("Waiting on deployment '%s' to be ready", deploy.PostgresName)
-					if err != nil {
-						logrus.Error(err)
-					}
-
-					return reconcile.Result{}, err
-				}
-			}
-
-			if !tests {
-				identityProviderPostgresPassword := instance.Spec.Auth.IdentityProviderPostgresPassword
-				identityProviderPostgresSecret := instance.Spec.Auth.IdentityProviderPostgresSecret
-				if len(identityProviderPostgresSecret) > 0 {
-					_, password, err := util.K8sclient.ReadSecret(identityProviderPostgresSecret, instance.Namespace)
-					if err != nil {
-						logrus.Errorf("Failed to read '%s' secret: %s", identityProviderPostgresSecret, err)
-						return reconcile.Result{Requeue: true, RequeueAfter: time.Second * 5}, err
-					}
-					identityProviderPostgresPassword = password
-				}
-				dbStatus := instance.Status.DbProvisoned
-				// provision Db and users for Che and Keycloak servers
-				if !dbStatus {
-					_, err := util.K8sclient.ExecIntoPod(
-						instance,
-						deploy.PostgresName,
-						func(cr *orgv1.CheCluster) (string, error) {
-							return identity_provider.GetPostgresProvisionCommand(identityProviderPostgresPassword), nil
-						},
-						"create Keycloak DB, user, privileges")
-					if err == nil {
-						for {
-							instance.Status.DbProvisoned = true
-							if err := r.UpdateCheCRStatus(instance, "status: provisioned with DB and user", "true"); err != nil &&
-								errors.IsConflict(err) {
-								instance, _ = r.GetCR(request)
-								continue
-							}
-							break
-						}
-					} else {
-						return reconcile.Result{Requeue: true, RequeueAfter: time.Second * 5}, err
-					}
-				}
+	if !deployContext.CheCluster.Spec.Database.ExternalDb {
+		postgres := postgres.NewPostgres(deployContext)
+		done, err = postgres.SyncAll()
+		if !done {
+			if err != nil {
+				logrus.Error(err)
 			}
+			return reconcile.Result{}, err
 		}
 	}
 
@@ -835,42 +669,45 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 	}
 
 	// create Che service and route
-	serviceStatus := server.SyncCheServiceToCluster(deployContext)
-	if !tests {
-		if !serviceStatus.Continue {
-			logrus.Infof("Waiting on service '%s' to be ready", deploy.CheServiceName)
-			if serviceStatus.Err != nil {
-				logrus.Error(serviceStatus.Err)
-			}
-
-			return reconcile.Result{Requeue: serviceStatus.Requeue}, serviceStatus.Err
+	done, err = server.SyncCheServiceToCluster(deployContext)
+	if !done {
+		if err != nil {
+			logrus.Error(err)
 		}
-	}
 
-	deployContext.InternalService.CheHost = fmt.Sprintf("http://%s.%s.svc:8080", deploy.CheServiceName, deployContext.CheCluster.Namespace)
+		return reconcile.Result{}, err
+	}
 
 	exposedServiceName := getServerExposingServiceName(instance)
 	cheHost := ""
 	if !isOpenShift {
-		ingress, err := deploy.SyncIngressToCluster(
+		_, done, err := deploy.SyncIngressToCluster(
 			deployContext,
 			cheFlavor,
 			instance.Spec.Server.CheHost,
+			"",
 			exposedServiceName,
 			8080,
 			deployContext.CheCluster.Spec.Server.CheServerIngress,
 			cheFlavor)
-		if !tests {
-			if ingress == nil {
-				logrus.Infof("Waiting on ingress '%s' to be ready", cheFlavor)
-				if err != nil {
-					logrus.Error(err)
-				}
-
-				return reconcile.Result{RequeueAfter: time.Second * 1}, err
+		if !done {
+			logrus.Infof("Waiting on ingress '%s' to be ready", cheFlavor)
+			if err != nil {
+				logrus.Error(err)
 			}
-			cheHost = ingress.Spec.Rules[0].Host
+
+			return reconcile.Result{RequeueAfter: time.Second * 1}, err
 		}
+
+		ingress := &v1beta1.Ingress{}
+		exists, err := deploy.GetNamespacedObject(deployContext, cheFlavor, ingress)
+		if !exists {
+			return reconcile.Result{}, err
+		} else if err != nil {
+			logrus.Error(err)
+			return reconcile.Result{}, err
+		}
+		cheHost = ingress.Spec.Rules[0].Host
 	} else {
 		customHost := instance.Spec.Server.CheHost
 		if deployContext.DefaultCheHost == customHost {
@@ -878,21 +715,29 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 			customHost = ""
 		}
 
-		route, err := deploy.SyncRouteToCluster(
+		done, err := deploy.SyncRouteToCluster(
 			deployContext,
 			cheFlavor,
 			customHost,
+			"/",
 			exposedServiceName,
 			8080,
 			deployContext.CheCluster.Spec.Server.CheServerRoute,
 			cheFlavor)
-		if route == nil {
-			logrus.Infof("Waiting on route '%s' to be ready", cheFlavor)
+		if !done {
 			if err != nil {
 				logrus.Error(err)
 			}
+			return reconcile.Result{}, err
+		}
 
-			return reconcile.Result{RequeueAfter: time.Second * 1}, err
+		route := &routev1.Route{}
+		exists, err := deploy.GetNamespacedObject(deployContext, cheFlavor, route)
+		if !exists {
+			if err != nil {
+				logrus.Error(err)
+			}
+			return reconcile.Result{}, err
 		}
 		cheHost = route.Spec.Host
 		if customHost == "" {
@@ -918,24 +763,54 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 		}
 	}
 
-	provisioned, err = devfile_registry.SyncDevfileRegistryToCluster(deployContext, cheHost)
-	if !tests {
-		if !provisioned {
+	if !instance.Spec.Server.ExternalPluginRegistry {
+		pluginRegistry := pluginregistry.NewPluginRegistry(deployContext)
+		done, err := pluginRegistry.SyncAll()
+		if !done {
 			if err != nil {
-				logrus.Errorf("Error provisioning '%s' to cluster: %v", deploy.DevfileRegistryName, err)
+				logrus.Error(err)
+			}
+			return reconcile.Result{}, err
+		}
+	} else {
+		if instance.Spec.Server.PluginRegistryUrl != instance.Status.PluginRegistryURL {
+			instance.Status.PluginRegistryURL = instance.Spec.Server.PluginRegistryUrl
+			if err := r.UpdateCheCRStatus(instance, "status: Plugin Registry URL", instance.Spec.Server.PluginRegistryUrl); err != nil {
+				return reconcile.Result{}, err
 			}
-			return reconcile.Result{RequeueAfter: time.Second * 1}, err
 		}
 	}
 
-	provisioned, err = plugin_registry.SyncPluginRegistryToCluster(deployContext, cheHost)
-	if !tests {
-		if !provisioned {
+	if !instance.Spec.Server.ExternalDevfileRegistry {
+		devfileRegistry := devfileregistry.NewDevfileRegistry(deployContext)
+		done, err := devfileRegistry.SyncAll()
+		if !done {
 			if err != nil {
-				logrus.Errorf("Error provisioning '%s' to cluster: %v", deploy.PluginRegistryName, err)
+				logrus.Error(err)
 			}
-			return reconcile.Result{RequeueAfter: time.Second * 1}, err
+			return reconcile.Result{}, err
 		}
+	} else {
+		done, err := deploy.DeleteNamespacedObject(deployContext, deploy.DevfileRegistryName, &corev1.ConfigMap{})
+		if !done {
+			return reconcile.Result{}, err
+		}
+
+		if instance.Spec.Server.DevfileRegistryUrl != instance.Status.DevfileRegistryURL {
+			instance.Status.DevfileRegistryURL = instance.Spec.Server.DevfileRegistryUrl
+			if err := r.UpdateCheCRStatus(instance, "status: Devfile Registry URL", instance.Spec.Server.DevfileRegistryUrl); err != nil {
+				return reconcile.Result{}, err
+			}
+		}
+	}
+
+	d := dashboard.NewDashboard(deployContext)
+	done, err = d.SyncAll()
+	if !done {
+		if err != nil {
+			logrus.Errorf("Error provisioning '%s' to cluster: %v", d.GetComponentName(), err)
+		}
+		return reconcile.Result{}, err
 	}
 
 	// create Che ConfigMap which is synced with CR and is not supposed to be manually edited
@@ -1055,26 +930,36 @@ func EvaluateCheServerVersion(cr *orgv1.CheCluster) string {
 
 func getDefaultCheHost(deployContext *deploy.DeployContext) (string, error) {
 	cheFlavor := deploy.DefaultCheFlavor(deployContext.CheCluster)
-	route, err := deploy.SyncRouteToCluster(
+	done, err := deploy.SyncRouteToCluster(
 		deployContext,
 		cheFlavor,
 		"",
+		"/",
 		getServerExposingServiceName(deployContext.CheCluster),
 		8080,
 		deployContext.CheCluster.Spec.Server.CheServerRoute,
 		cheFlavor)
-	if route == nil {
-		logrus.Infof("Waiting on route '%s' to be ready", cheFlavor)
+	if !done {
 		if err != nil {
 			logrus.Error(err)
 		}
 		return "", err
 	}
+
+	route := &routev1.Route{}
+	exists, err := deploy.GetNamespacedObject(deployContext, cheFlavor, route)
+	if !exists {
+		if err != nil {
+			logrus.Error(err)
+		}
+		return "", err
+	}
+
 	return route.Spec.Host, nil
 }
 
 func getServerExposingServiceName(cr *orgv1.CheCluster) string {
-	if cr.Spec.Server.ServerExposureStrategy == "single-host" && deploy.GetSingleHostExposureType(cr) == "gateway" {
+	if util.GetServerExposureStrategy(cr) == "single-host" && deploy.GetSingleHostExposureType(cr) == "gateway" {
 		return gateway.GatewayServiceName
 	}
 	return deploy.CheServiceName
@@ -1223,7 +1108,13 @@ func (r *ReconcileChe) reconcileFinalizers(deployContext *deploy.DeployContext)
 		}
 	}
 
-	if err := r.reconcileWorkspacePermissionsFinalizer(deployContext); err != nil {
+	if util.IsOpenShift4 && util.IsInitialOpenShiftOAuthUserEnabled(deployContext.CheCluster) {
+		if !deployContext.CheCluster.ObjectMeta.DeletionTimestamp.IsZero() {
+			r.userHandler.DeleteOAuthInitialUser(deployContext)
+		}
+	}
+
+	if _, err := r.reconcileWorkspacePermissionsFinalizers(deployContext); err != nil {
 		logrus.Error(err)
 	}
 
