@@ -26,18 +26,10 @@ type ProvisioningStatus struct {
 }
 
 type DeployContext struct {
-	CheCluster      *orgv1.CheCluster
-	ClusterAPI      ClusterAPI
-	Proxy           *Proxy
-	InternalService InternalService
-	DefaultCheHost  string
-}
-
-type InternalService struct {
-	KeycloakHost        string
-	DevfileRegistryHost string
-	PluginRegistryHost  string
-	CheHost             string
+	CheCluster     *orgv1.CheCluster
+	ClusterAPI     ClusterAPI
+	Proxy          *Proxy
+	DefaultCheHost string
 }
 
 type ClusterAPI struct {
@@ -63,3 +55,7 @@ type Proxy struct {
 	NoProxy          string
 	TrustedCAMapName string
 }
+
+type Syncable interface {
+	Sync() (bool, error)
+}
