@@ -9,7 +9,6 @@
 // Contributors:
 //   Red Hat, Inc. - initial API and implementation
 //
-// REMINDER: when updating versions below, see also pkg/apis/org/v1/che_types.go and deploy/crds/org_v1_che_cr.yaml
 package deploy
 
 import (
@@ -30,6 +29,9 @@ import (
 var (
 	defaultCheServerImage                      string
 	defaultCheVersion                          string
+	defaultDashboardImage                      string
+	defaultDevworkspaceCheOperatorImage        string
+	defaultDevworkspaceControllerImage         string
 	defaultPluginRegistryImage                 string
 	defaultDevfileRegistryImage                string
 	defaultCheTLSSecretsCreationJobImage       string
@@ -53,8 +55,8 @@ const (
 	DefaultChePostgresHostName = "postgres"
 	DefaultChePostgresPort     = "5432"
 	DefaultChePostgresDb       = "dbche"
-	DefaultPvcStrategy         = "per-workspace"
-	DefaultPvcClaimSize        = "1Gi"
+	DefaultPvcStrategy         = "common"
+	DefaultPvcClaimSize        = "10Gi"
 	DefaultIngressClass        = "nginx"
 
 	DefaultKeycloakAdminUserName   = "admin"
@@ -118,6 +120,11 @@ const (
 	PostgresName         = "postgres"
 
 	// limits
+	DefaultDashboardMemoryLimit   = "256Mi"
+	DefaultDashboardMemoryRequest = "32Mi"
+	DefaultDashboardCpuLimit      = "500m"
+	DefaultDashboardCpuRequest    = "100m"
+
 	DefaultPluginRegistryMemoryLimit   = "256Mi"
 	DefaultPluginRegistryMemoryRequest = "32Mi"
 	DefaultPluginRegistryCpuLimit      = "500m"
@@ -161,6 +168,9 @@ func InitDefaultsFromFile(defaultsPath string) {
 
 	defaultCheVersion = util.GetDeploymentEnv(operatorDeployment, "CHE_VERSION")
 	defaultCheServerImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_che_server"))
+	defaultDashboardImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_dashboard"))
+	defaultDevworkspaceCheOperatorImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_che_operator"))
+	defaultDevworkspaceControllerImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_controller"))
 	defaultPluginRegistryImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_plugin_registry"))
 	defaultDevfileRegistryImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_devfile_registry"))
 	defaultPvcJobsImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_pvc_jobs"))
@@ -273,6 +283,18 @@ func DefaultPostgresImage(cr *orgv1.CheCluster) string {
 	return patchDefaultImageName(cr, defaultPostgresImage)
 }
 
+func DefaultDashboardImage(cr *orgv1.CheCluster) string {
+	return patchDefaultImageName(cr, defaultDashboardImage)
+}
+
+func DefaultDevworkspaceControllerImage(cr *orgv1.CheCluster) string {
+	return patchDefaultImageName(cr, defaultDevworkspaceControllerImage)
+}
+
+func DefaultDevworkspaceCheOperatorImage(cr *orgv1.CheCluster) string {
+	return patchDefaultImageName(cr, defaultDevworkspaceCheOperatorImage)
+}
+
 func DefaultKeycloakImage(cr *orgv1.CheCluster) string {
 	return patchDefaultImageName(cr, defaultKeycloakImage)
 }
@@ -399,6 +421,9 @@ func getOrganizationFromImage(image string) string {
 func InitDefaultsFromEnv() {
 	defaultCheVersion = getDefaultFromEnv("CHE_VERSION")
 	defaultCheServerImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_che_server"))
+	defaultDashboardImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_dashboard"))
+	defaultDevworkspaceCheOperatorImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_che_operator"))
+	defaultDevworkspaceControllerImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_controller"))
 	defaultPluginRegistryImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_plugin_registry"))
 	defaultDevfileRegistryImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_devfile_registry"))
 	defaultPvcJobsImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_pvc_jobs"))
