@@ -13,7 +13,6 @@ package identity_provider
 
 import (
 	"errors"
-	"fmt"
 	"strings"
 
 	orgv1 "github.com/eclipse-che/che-operator/pkg/apis/org/v1"
@@ -36,6 +35,7 @@ var (
 		syncOpenShiftIdentityProvider,
 		SyncGitHubOAuth,
 	}
+	keycloakClientURLsUpdated = false
 )
 
 // SyncIdentityProviderToCluster instantiates the identity provider (Keycloak) in the cluster. Returns true if
@@ -64,14 +64,12 @@ func SyncIdentityProviderToCluster(deployContext *deploy.DeployContext) (bool, e
 }
 
 func syncService(deployContext *deploy.DeployContext) (bool, error) {
-	serviceStatus := deploy.SyncServiceToCluster(
+	return deploy.SyncServiceToCluster(
 		deployContext,
 		deploy.IdentityProviderName,
 		[]string{"http"},
 		[]int32{8080},
 		deploy.IdentityProviderName)
-
-	return serviceStatus.Continue, serviceStatus.Err
 }
 
 func syncExposure(deployContext *deploy.DeployContext) (bool, error) {
@@ -82,18 +80,14 @@ func syncExposure(deployContext *deploy.DeployContext) (bool, error) {
 		false: "http"})[cr.Spec.Server.TlsSupport]
 	endpoint, done, err := expose.Expose(
 		deployContext,
-		cr.Spec.Server.CheHost,
 		deploy.IdentityProviderName,
 		cr.Spec.Auth.IdentityProviderRoute,
-		cr.Spec.Auth.IdentityProviderIngress,
-		deploy.IdentityProviderName)
+		cr.Spec.Auth.IdentityProviderIngress)
 	if !done {
 		return false, err
 	}
 
 	keycloakURL := protocol + "://" + endpoint
-	deployContext.InternalService.KeycloakHost = fmt.Sprintf("%s://%s.%s.svc:%d", "http", deploy.IdentityProviderName, cr.Namespace, 8080)
-
 	if cr.Spec.Auth.IdentityProviderURL != keycloakURL {
 		cr.Spec.Auth.IdentityProviderURL = keycloakURL
 		if err := deploy.UpdateCheCRSpec(deployContext, "Keycloak URL", keycloakURL); err != nil {
@@ -128,6 +122,17 @@ func syncKeycloakResources(deployContext *deploy.DeployContext) (bool, error) {
 				break
 			}
 		}
+		if !keycloakClientURLsUpdated {
+			if _, err := util.K8sclient.ExecIntoPod(
+				deployContext.CheCluster,
+				deploy.IdentityProviderName,
+				GetKeycloakUpdateCommand,
+				"Update redirect URI-s"); err != nil {
+				return false, err
+			} else {
+				keycloakClientURLsUpdated = true
+			}
+		}
 	}
 
 	return true, nil
@@ -165,7 +170,7 @@ func SyncOpenShiftIdentityProviderItems(deployContext *deploy.DeployContext) (bo
 	keycloakURL := cr.Spec.Auth.IdentityProviderURL
 	cheFlavor := deploy.DefaultCheFlavor(cr)
 	keycloakRealm := util.GetValue(cr.Spec.Auth.IdentityProviderRealm, cheFlavor)
-	oAuthClient := deploy.NewOAuthClient(oAuthClientName, oauthSecret, keycloakURL, keycloakRealm, util.IsOpenShift4)
+	oAuthClient := deploy.GetOAuthClientSpec(oAuthClientName, oauthSecret, keycloakURL, keycloakRealm, util.IsOpenShift4)
 	provisioned, err := deploy.Sync(deployContext, oAuthClient, oAuthClientDiffOpts)
 	if !provisioned {
 		return false, err
