@@ -12,8 +12,6 @@
 package deploy
 
 import (
-	"context"
-	"fmt"
 	"reflect"
 	"strconv"
 
@@ -21,14 +19,9 @@ import (
 	"github.com/eclipse-che/che-operator/pkg/util"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
-	"github.com/sirupsen/logrus"
 	"k8s.io/api/extensions/v1beta1"
-	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/intstr"
-	runtimeClient "sigs.k8s.io/controller-runtime/pkg/client"
-	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
 )
 
 var ingressDiffOpts = cmp.Options{
@@ -38,94 +31,37 @@ var ingressDiffOpts = cmp.Options{
 	}),
 }
 
+// SyncIngressToCluster creates ingress to expose service with the set settings
+// host and path are evaluated if they are empty
 func SyncIngressToCluster(
 	deployContext *DeployContext,
 	name string,
 	host string,
+	path string,
 	serviceName string,
 	servicePort int,
 	ingressCustomSettings orgv1.IngressCustomSettings,
-	component string) (*v1beta1.Ingress, error) {
+	component string) (endpointUrl string, done bool, err error) {
 
-	specIngress, err := GetSpecIngress(deployContext, name, host, serviceName, servicePort, ingressCustomSettings, component)
-	if err != nil {
-		return nil, err
-	}
-
-	clusterIngress, err := GetClusterIngress(specIngress.Name, specIngress.Namespace, deployContext.ClusterAPI.Client)
-	if err != nil {
-		return nil, err
-	}
-
-	if clusterIngress == nil {
-		logrus.Infof("Creating a new object: %s, name %s", specIngress.Kind, specIngress.Name)
-		err := deployContext.ClusterAPI.Client.Create(context.TODO(), specIngress)
-		return nil, err
-	}
-
-	diff := cmp.Diff(clusterIngress, specIngress, ingressDiffOpts)
-	if len(diff) > 0 {
-		logrus.Infof("Updating existed object: %s, name: %s", clusterIngress.Kind, clusterIngress.Name)
-		fmt.Printf("Difference:\n%s", diff)
-
-		err := deployContext.ClusterAPI.Client.Delete(context.TODO(), clusterIngress)
-		if err != nil {
-			return nil, err
-		}
-
-		err = deployContext.ClusterAPI.Client.Create(context.TODO(), specIngress)
-		return nil, err
-	}
-
-	return clusterIngress, nil
+	ingressUrl, ingressSpec := GetIngressSpec(deployContext, name, host, path, serviceName, servicePort, ingressCustomSettings, component)
+	sync, err := Sync(deployContext, ingressSpec, ingressDiffOpts)
+	return ingressUrl, sync, err
 }
 
-// DeleteIngressIfExists removes specified ingress if any
-func DeleteIngressIfExists(name string, deployContext *DeployContext) error {
-	ingress, err := GetClusterIngress(name, deployContext.CheCluster.Namespace, deployContext.ClusterAPI.Client)
-	if err != nil {
-		return err
-	}
-
-	if ingress != nil {
-		err = deployContext.ClusterAPI.Client.Delete(context.TODO(), ingress)
-		if err != nil {
-			return err
-		}
-	}
-
-	return nil
-}
-
-// GetClusterIngress returns actual ingress config by provided name and namespace
-func GetClusterIngress(name string, namespace string, client runtimeClient.Client) (*v1beta1.Ingress, error) {
-	ingress := &v1beta1.Ingress{}
-	namespacedName := types.NamespacedName{
-		Namespace: namespace,
-		Name:      name,
-	}
-	err := client.Get(context.TODO(), namespacedName, ingress)
-	if err != nil {
-		if errors.IsNotFound(err) {
-			return nil, nil
-		}
-		return nil, err
-	}
-	return ingress, nil
-}
-
-// GetSpecIngress returns expected ingress config for given parameters
-func GetSpecIngress(
+// GetIngressSpec returns expected ingress config for given parameters
+// host and path are evaluated if they are empty
+func GetIngressSpec(
 	deployContext *DeployContext,
 	name string,
 	host string,
+	path string,
 	serviceName string,
 	servicePort int,
 	ingressCustomSettings orgv1.IngressCustomSettings,
-	component string) (*v1beta1.Ingress, error) {
+	component string) (ingressUrl string, i *v1beta1.Ingress) {
 
 	tlsSupport := deployContext.CheCluster.Spec.Server.TlsSupport
-	ingressStrategy := util.GetServerExposureStrategy(deployContext.CheCluster, DefaultServerExposureStrategy)
+	ingressStrategy := util.GetServerExposureStrategy(deployContext.CheCluster)
 	ingressDomain := deployContext.CheCluster.Spec.K8s.IngressDomain
 	ingressClass := util.GetValue(deployContext.CheCluster.Spec.K8s.IngressClass, DefaultIngressClass)
 	labels := GetLabels(deployContext.CheCluster, component)
@@ -133,7 +69,7 @@ func GetSpecIngress(
 
 	if host == "" {
 		if ingressStrategy == "multi-host" {
-			host = name + "-" + deployContext.CheCluster.Namespace + "." + ingressDomain
+			host = component + "-" + deployContext.CheCluster.Namespace + "." + ingressDomain
 		} else if ingressStrategy == "single-host" {
 			host = ingressDomain
 		}
@@ -141,21 +77,17 @@ func GetSpecIngress(
 
 	tlsSecretName := util.GetValue(deployContext.CheCluster.Spec.K8s.TlsSecretName, "")
 	if tlsSupport {
-		if name == DefaultCheFlavor(deployContext.CheCluster) && deployContext.CheCluster.Spec.Server.CheHostTLSSecret != "" {
+		if component == DefaultCheFlavor(deployContext.CheCluster) && deployContext.CheCluster.Spec.Server.CheHostTLSSecret != "" {
 			tlsSecretName = deployContext.CheCluster.Spec.Server.CheHostTLSSecret
 		}
 	}
 
-	path := "/"
-	if ingressStrategy != "multi-host" {
-		switch name {
-		case IdentityProviderName:
-			path = "/auth"
-		case DevfileRegistryName:
-			path = "/" + DevfileRegistryName + "/(.*)"
-		case PluginRegistryName:
-			path = "/" + PluginRegistryName + "/(.*)"
-		}
+	var endpointPath, ingressPath string
+	if path == "" {
+		endpointPath, ingressPath = evaluatePath(component, ingressStrategy)
+	} else {
+		ingressPath = path
+		endpointPath = path
 	}
 
 	annotations := map[string]string{
@@ -164,7 +96,7 @@ func GetSpecIngress(
 		"nginx.ingress.kubernetes.io/proxy-connect-timeout": "3600",
 		"nginx.ingress.kubernetes.io/ssl-redirect":          strconv.FormatBool(tlsSupport),
 	}
-	if ingressStrategy != "multi-host" && (name == DevfileRegistryName || name == PluginRegistryName) {
+	if ingressStrategy != "multi-host" && (component == DevfileRegistryName || component == PluginRegistryName) {
 		annotations["nginx.ingress.kubernetes.io/rewrite-target"] = "/$1"
 	}
 
@@ -191,7 +123,7 @@ func GetSpecIngress(
 										ServiceName: serviceName,
 										ServicePort: intstr.FromInt(servicePort),
 									},
-									Path: path,
+									Path: ingressPath,
 								},
 							},
 						},
@@ -212,10 +144,35 @@ func GetSpecIngress(
 		}
 	}
 
-	err := controllerutil.SetControllerReference(deployContext.CheCluster, ingress, deployContext.ClusterAPI.Scheme)
-	if err != nil {
-		return nil, err
+	return host + endpointPath, ingress
+}
+
+// evaluatePath evaluates ingress path (one which is used for rule)
+// and endpoint path (one which client should use during endpoint accessing)
+func evaluatePath(component, ingressStrategy string) (endpointPath, ingressPath string) {
+	if ingressStrategy == "multi-host" {
+		ingressPath = "/"
+		endpointPath = "/"
+		// Keycloak needs special rule in multihost. It's exposed on / which redirects to /auth
+		// clients which does not support redirects needs /auth be explicitely set
+		if component == IdentityProviderName {
+			endpointPath = "/auth"
+		}
+	} else {
+		switch component {
+		case IdentityProviderName:
+			endpointPath = "/auth"
+			ingressPath = endpointPath + "/(.*)"
+		case DevfileRegistryName:
+			fallthrough
+		case PluginRegistryName:
+			endpointPath = "/" + component
+			ingressPath = endpointPath + "/(.*)"
+		default:
+			ingressPath = "/"
+			endpointPath = "/"
+		}
+
 	}
-
-	return ingress, nil
+	return endpointPath, ingressPath
 }
