@@ -14,9 +14,9 @@ package server
 import (
 	"encoding/json"
 	"fmt"
-	"net/url"
 	"os"
 	"strconv"
+	"strings"
 
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 
@@ -101,6 +101,17 @@ func SyncCheConfigMapToCluster(deployContext *deploy.DeployContext) (bool, error
 func GetCheConfigMapData(deployContext *deploy.DeployContext) (cheEnv map[string]string, err error) {
 	cheHost := deployContext.CheCluster.Spec.Server.CheHost
 	keycloakURL := deployContext.CheCluster.Spec.Auth.IdentityProviderURL
+
+	// Adds `/auth` for external identity providers.
+	// If identity provide is deployed by operator then `/auth` is already added.
+	if deployContext.CheCluster.Spec.Auth.ExternalIdentityProvider && !strings.HasSuffix(keycloakURL, "/auth") {
+		if strings.HasSuffix(keycloakURL, "/") {
+			keycloakURL = keycloakURL + "auth"
+		} else {
+			keycloakURL = keycloakURL + "/auth"
+		}
+	}
+
 	if err != nil {
 		logrus.Errorf("Failed to get current infra: %s", err)
 	}
@@ -158,7 +169,7 @@ func GetCheConfigMapData(deployContext *deploy.DeployContext) (cheEnv map[string
 	chePostgresDb := util.GetValue(deployContext.CheCluster.Spec.Database.ChePostgresDb, deploy.DefaultChePostgresDb)
 	keycloakRealm := util.GetValue(deployContext.CheCluster.Spec.Auth.IdentityProviderRealm, cheFlavor)
 	keycloakClientId := util.GetValue(deployContext.CheCluster.Spec.Auth.IdentityProviderClientId, cheFlavor+"-public")
-	ingressStrategy := util.GetServerExposureStrategy(deployContext.CheCluster, deploy.DefaultServerExposureStrategy)
+	ingressStrategy := util.GetServerExposureStrategy(deployContext.CheCluster)
 	ingressClass := util.GetValue(deployContext.CheCluster.Spec.K8s.IngressClass, deploy.DefaultIngressClass)
 	devfileRegistryURL := deployContext.CheCluster.Status.DevfileRegistryURL
 	pluginRegistryURL := deployContext.CheCluster.Status.PluginRegistryURL
@@ -175,33 +186,27 @@ func GetCheConfigMapData(deployContext *deploy.DeployContext) (cheEnv map[string
 	var keycloakInternalURL, pluginRegistryInternalURL, devfileRegistryInternalURL, cheInternalAPI, webSocketEndpoint, webSocketEndpointMinor string
 
 	if deployContext.CheCluster.Spec.Server.UseInternalClusterSVCNames && !deployContext.CheCluster.Spec.Auth.ExternalIdentityProvider {
-		keycloakInternalURL = deployContext.InternalService.KeycloakHost
+		keycloakInternalURL = fmt.Sprintf("%s://%s.%s.svc:8080/auth", "http", deploy.IdentityProviderName, deployContext.CheCluster.Namespace)
 	} else {
 		keycloakInternalURL = keycloakURL
 	}
 
 	if deployContext.CheCluster.Spec.Server.UseInternalClusterSVCNames && !deployContext.CheCluster.Spec.Server.ExternalDevfileRegistry {
-		devfileRegistryInternalURL = deployContext.InternalService.DevfileRegistryHost
+		devfileRegistryInternalURL = fmt.Sprintf("http://%s.%s.svc:8080", deploy.DevfileRegistryName, deployContext.CheCluster.Namespace)
 	} else {
 		devfileRegistryInternalURL = devfileRegistryURL
 	}
 
 	if deployContext.CheCluster.Spec.Server.UseInternalClusterSVCNames && !deployContext.CheCluster.Spec.Server.ExternalPluginRegistry {
-		pluginRegistryInternalURL = deployContext.InternalService.PluginRegistryHost
+		pluginRegistryInternalURL = fmt.Sprintf("http://%s.%s.svc:8080/v3", deploy.PluginRegistryName, deployContext.CheCluster.Namespace)
 	} else {
 		pluginRegistryInternalURL = pluginRegistryURL
 	}
 
 	if deployContext.CheCluster.Spec.Server.UseInternalClusterSVCNames {
-		cheInternalAPI = deployContext.InternalService.CheHost + "/api"
-
-		u, err := url.Parse(deployContext.InternalService.CheHost)
-		if err != nil {
-			return nil, err
-		}
-
-		webSocketEndpoint = "ws://" + u.Host + "/api/websocket"
-		webSocketEndpointMinor = "ws://" + u.Host + "/api/websocket-minor"
+		cheInternalAPI = fmt.Sprintf("http://%s.%s.svc:8080/api", deploy.CheServiceName, deployContext.CheCluster.Namespace)
+		webSocketEndpoint = fmt.Sprintf("ws://%s.%s.svc:8080/api/websocket", deploy.CheServiceName, deployContext.CheCluster.Namespace)
+		webSocketEndpointMinor = fmt.Sprintf("ws://%s.%s.svc:8080/api/websocket-minor", deploy.CheServiceName, deployContext.CheCluster.Namespace)
 	} else {
 		cheInternalAPI = cheAPI
 
@@ -261,8 +266,8 @@ func GetCheConfigMapData(deployContext *deploy.DeployContext) (cheEnv map[string
 	}
 
 	if cheMultiUser == "true" {
-		data.KeycloakURL = keycloakURL + "/auth"
-		data.KeycloakInternalURL = keycloakInternalURL + "/auth"
+		data.KeycloakURL = keycloakURL
+		data.KeycloakInternalURL = keycloakInternalURL
 		data.KeycloakRealm = keycloakRealm
 		data.KeycloakClientId = keycloakClientId
 		data.DatabaseURL = "jdbc:postgresql://" + chePostgresHostName + ":" + chePostgresPort + "/" + chePostgresDb
@@ -292,13 +297,14 @@ func GetCheConfigMapData(deployContext *deploy.DeployContext) (cheEnv map[string
 
 		// Add TLS key and server certificate to properties when user workspaces should be created in another
 		// than Che server namespace, from where the Che TLS secret is not accessable
-		if !util.IsWorkspaceInSameNamespaceWithChe(deployContext.CheCluster) {
+		if util.IsWorkspaceInDifferentNamespaceThanChe(deployContext.CheCluster) {
 			if deployContext.CheCluster.Spec.K8s.TlsSecretName != "" {
-				cheTLSSecret, err := deploy.GetSecret(deployContext, deployContext.CheCluster.Spec.K8s.TlsSecretName, deployContext.CheCluster.ObjectMeta.Namespace)
+				cheTLSSecret := &corev1.Secret{}
+				exists, err := deploy.GetNamespacedObject(deployContext, deployContext.CheCluster.Spec.K8s.TlsSecretName, cheTLSSecret)
 				if err != nil {
 					return nil, err
 				}
-				if cheTLSSecret == nil {
+				if !exists {
 					return nil, fmt.Errorf("%s secret not found", deployContext.CheCluster.Spec.K8s.TlsSecretName)
 				} else {
 					if _, exists := cheTLSSecret.Data["tls.key"]; !exists {
