@@ -102,13 +102,12 @@ func TestNewCheConfigMap(t *testing.T) {
 
 func TestConfigMap(t *testing.T) {
 	type testCase struct {
-		name            string
-		isOpenShift     bool
-		isOpenShift4    bool
-		initObjects     []runtime.Object
-		cheCluster      *orgv1.CheCluster
-		internalService deploy.InternalService
-		expectedData    map[string]string
+		name         string
+		isOpenShift  bool
+		isOpenShift4 bool
+		initObjects  []runtime.Object
+		cheCluster   *orgv1.CheCluster
+		expectedData map[string]string
 	}
 
 	testCases := []testCase{
@@ -169,6 +168,10 @@ func TestConfigMap(t *testing.T) {
 		{
 			name: "Test k8s data, with internal cluster svc names",
 			cheCluster: &orgv1.CheCluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "eclipse-che",
+					Namespace: "eclipse-che",
+				},
 				Spec: orgv1.CheClusterSpec{
 					Server: orgv1.CheClusterSpecServer{
 						CheHost:                    "che-host",
@@ -176,17 +179,18 @@ func TestConfigMap(t *testing.T) {
 					},
 				},
 			},
-			internalService: deploy.InternalService{
-				CheHost: "http://che-host-internal.svc:8080",
-			},
 			expectedData: map[string]string{
-				"CHE_WEBSOCKET_ENDPOINT":        "ws://che-host-internal.svc:8080/api/websocket",
-				"CHE_WEBSOCKET_ENDPOINT__MINOR": "ws://che-host-internal.svc:8080/api/websocket-minor",
+				"CHE_WEBSOCKET_ENDPOINT":        "ws://che-host.eclipse-che.svc:8080/api/websocket",
+				"CHE_WEBSOCKET_ENDPOINT__MINOR": "ws://che-host.eclipse-che.svc:8080/api/websocket-minor",
 			},
 		},
 		{
 			name: "Test k8s data, without internal cluster svc names",
 			cheCluster: &orgv1.CheCluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "eclipse-che",
+					Namespace: "eclipse-che",
+				},
 				Spec: orgv1.CheClusterSpec{
 					Server: orgv1.CheClusterSpecServer{
 						CheHost:                    "che-host",
@@ -194,9 +198,6 @@ func TestConfigMap(t *testing.T) {
 					},
 				},
 			},
-			internalService: deploy.InternalService{
-				CheHost: "http://che-host-internal.svc:8080",
-			},
 			expectedData: map[string]string{
 				"CHE_WEBSOCKET_ENDPOINT":        "ws://che-host/api/websocket",
 				"CHE_WEBSOCKET_ENDPOINT__MINOR": "ws://che-host/api/websocket-minor",
@@ -213,8 +214,7 @@ func TestConfigMap(t *testing.T) {
 			nonCachedClient := fake.NewFakeClientWithScheme(scheme.Scheme, testCase.initObjects...)
 
 			deployContext := &deploy.DeployContext{
-				InternalService: testCase.internalService,
-				CheCluster:      testCase.cheCluster,
+				CheCluster: testCase.cheCluster,
 				ClusterAPI: deploy.ClusterAPI{
 					Client:          cli,
 					NonCachedClient: nonCachedClient,
@@ -482,6 +482,26 @@ func TestShouldSetUpCorrectlyInternalDevfileRegistryServiceURL(t *testing.T) {
 				"CHE_WORKSPACE_DEVFILE__REGISTRY__INTERNAL__URL": "http://devfile-registry.eclipse-che.svc:8080",
 			},
 		},
+		{
+			name: "Kubernetes strategy should be set correctly",
+			cheCluster: &orgv1.CheCluster{
+				TypeMeta: metav1.TypeMeta{
+					Kind:       "CheCluster",
+					APIVersion: "org.eclipse.che/v1",
+				},
+				ObjectMeta: metav1.ObjectMeta{
+					Namespace: "eclipse-che",
+				},
+				Spec: orgv1.CheClusterSpec{
+					K8s: orgv1.CheClusterSpecK8SOnly{
+						IngressStrategy: "single-host",
+					},
+				},
+			},
+			expectedData: map[string]string{
+				"CHE_INFRA_KUBERNETES_SERVER__STRATEGY": "single-host",
+			},
+		},
 	}
 
 	for _, testCase := range testCases {
@@ -500,9 +520,6 @@ func TestShouldSetUpCorrectlyInternalDevfileRegistryServiceURL(t *testing.T) {
 					Scheme:          scheme.Scheme,
 				},
 				Proxy: &deploy.Proxy{},
-				InternalService: deploy.InternalService{
-					DevfileRegistryHost: "http://devfile-registry.eclipse-che.svc:8080",
-				},
 			}
 
 			util.IsOpenShift = testCase.isOpenShift
@@ -655,9 +672,6 @@ func TestShouldSetUpCorrectlyInternalPluginRegistryServiceURL(t *testing.T) {
 					Scheme:          scheme.Scheme,
 				},
 				Proxy: &deploy.Proxy{},
-				InternalService: deploy.InternalService{
-					PluginRegistryHost: "http://plugin-registry.eclipse-che.svc:8080/v3",
-				},
 			}
 
 			util.IsOpenShift = testCase.isOpenShift
@@ -750,9 +764,6 @@ func TestShouldSetUpCorrectlyInternalCheServerURL(t *testing.T) {
 					Scheme:          scheme.Scheme,
 				},
 				Proxy: &deploy.Proxy{},
-				InternalService: deploy.InternalService{
-					CheHost: "http://che-host.eclipse-che.svc:8080",
-				},
 			}
 
 			util.IsOpenShift = testCase.isOpenShift
@@ -780,7 +791,7 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 
 	testCases := []testCase{
 		{
-			name: "Should use 'external' public identity provider url, when internal network is enabled",
+			name: "Should use 'external' public identity provider url, when internal network is enabled #1",
 			cheCluster: &orgv1.CheCluster{
 				TypeMeta: metav1.TypeMeta{
 					Kind:       "CheCluster",
@@ -802,6 +813,33 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 			},
 			expectedData: map[string]string{
 				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "http://external-keycloak/auth",
+				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://external-keycloak/auth",
+			},
+		},
+		{
+			name: "Should use 'external' public identity provider url, when internal network is enabled #2",
+			cheCluster: &orgv1.CheCluster{
+				TypeMeta: metav1.TypeMeta{
+					Kind:       "CheCluster",
+					APIVersion: "org.eclipse.che/v1",
+				},
+				ObjectMeta: metav1.ObjectMeta{
+					Namespace: "eclipse-che",
+				},
+				Spec: orgv1.CheClusterSpec{
+					Server: orgv1.CheClusterSpecServer{
+						UseInternalClusterSVCNames: true,
+					},
+					Auth: orgv1.CheClusterSpecAuth{
+						OpenShiftoAuth:           util.NewBoolPointer(false),
+						ExternalIdentityProvider: true,
+						IdentityProviderURL:      "http://external-keycloak/auth",
+					},
+				},
+			},
+			expectedData: map[string]string{
+				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "http://external-keycloak/auth",
+				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://external-keycloak/auth",
 			},
 		},
 		{
@@ -827,6 +865,7 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 			},
 			expectedData: map[string]string{
 				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "http://external-keycloak/auth",
+				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://external-keycloak/auth",
 			},
 		},
 		{
@@ -846,15 +885,13 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 					Auth: orgv1.CheClusterSpecAuth{
 						OpenShiftoAuth:           util.NewBoolPointer(false),
 						ExternalIdentityProvider: false,
-						IdentityProviderURL:      "http://keycloak",
+						IdentityProviderURL:      "http://keycloak/auth",
 					},
 				},
-				Status: orgv1.CheClusterStatus{
-					KeycloakURL: "http://keycloak",
-				},
 			},
 			expectedData: map[string]string{
 				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "http://keycloak/auth",
+				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://keycloak/auth",
 			},
 		},
 		{
@@ -874,12 +911,13 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 					Auth: orgv1.CheClusterSpecAuth{
 						OpenShiftoAuth:           util.NewBoolPointer(false),
 						ExternalIdentityProvider: false,
-						IdentityProviderURL:      "http://keycloak",
+						IdentityProviderURL:      "http://keycloak/auth",
 					},
 				},
 			},
 			expectedData: map[string]string{
 				"CHE_KEYCLOAK_AUTH__INTERNAL__SERVER__URL": "http://keycloak.eclipse-che.svc:8080/auth",
+				"CHE_KEYCLOAK_AUTH__SERVER__URL":           "http://keycloak/auth",
 			},
 		},
 	}
@@ -900,9 +938,6 @@ func TestShouldSetUpCorrectlyInternalIdentityProviderServiceURL(t *testing.T) {
 					Scheme:          scheme.Scheme,
 				},
 				Proxy: &deploy.Proxy{},
-				InternalService: deploy.InternalService{
-					KeycloakHost: "http://keycloak.eclipse-che.svc:8080",
-				},
 			}
 
 			util.IsOpenShift = testCase.isOpenShift
