@@ -1,8 +1,20 @@
+//
+// Copyright (c) 2021 Red Hat, Inc.
+// This program and the accompanying materials are made
+// available under the terms of the Eclipse Public License 2.0
+// which is available at https://www.eclipse.org/legal/epl-2.0/
+//
+// SPDX-License-Identifier: EPL-2.0
+//
+// Contributors:
+//   Red Hat, Inc. - initial API and implementation
+//
 package deploy
 
 import (
 	"context"
 	"fmt"
+	"reflect"
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/sirupsen/logrus"
@@ -130,8 +142,7 @@ func CreateIfNotExists(deployContext *DeployContext, blueprint metav1.Object) (b
 		return false, err
 	}
 
-	kind := runtimeObject.GetObjectKind().GroupVersionKind().Kind
-	logrus.Infof("Creating a new object: %s, name: %s", kind, blueprint.GetName())
+	logrus.Infof("Creating a new object: %s, name: %s", getObjectType(blueprint), blueprint.GetName())
 
 	err = setOwnerReferenceIfNeeded(deployContext, blueprint)
 	if err != nil {
@@ -156,8 +167,7 @@ func Create(deployContext *DeployContext, blueprint metav1.Object) (bool, error)
 		return false, fmt.Errorf("object %T is not a runtime.Object. Cannot sync it", runtimeObject)
 	}
 
-	kind := runtimeObject.GetObjectKind().GroupVersionKind().Kind
-	logrus.Infof("Creating a new object: %s, name: %s", kind, blueprint.GetName())
+	logrus.Infof("Creating a new object: %s, name: %s", getObjectType(blueprint), blueprint.GetName())
 
 	err := setOwnerReferenceIfNeeded(deployContext, blueprint)
 	if err != nil {
@@ -202,10 +212,29 @@ func Update(deployContext *DeployContext, actual runtime.Object, blueprint metav
 
 	diff := cmp.Diff(actual, blueprint, diffOpts)
 	if len(diff) > 0 {
-		kind := actual.GetObjectKind().GroupVersionKind().Kind
-		logrus.Infof("Updating existing object: %s, name: %s", kind, actualMeta.GetName())
+		logrus.Infof("Updating existing object: %s, name: %s", getObjectType(actualMeta), actualMeta.GetName())
 		fmt.Printf("Difference:\n%s", diff)
 
+		targetLabels := map[string]string{}
+		targetAnnos := map[string]string{}
+
+		for k, v := range actualMeta.GetAnnotations() {
+			targetAnnos[k] = v
+		}
+		for k, v := range actualMeta.GetLabels() {
+			targetLabels[k] = v
+		}
+
+		for k, v := range blueprint.GetAnnotations() {
+			targetAnnos[k] = v
+		}
+		for k, v := range blueprint.GetLabels() {
+			targetLabels[k] = v
+		}
+
+		blueprint.SetAnnotations(targetAnnos)
+		blueprint.SetLabels(targetLabels)
+
 		client := getClientForObject(actualMeta.GetNamespace(), deployContext)
 		if isUpdateUsingDeleteCreate(actual.GetObjectKind().GroupVersionKind().Kind) {
 			done, err := doDelete(client, actual)
@@ -263,8 +292,7 @@ func doDeleteByKey(client client.Client, scheme *runtime.Scheme, key client.Obje
 		return false, err
 	}
 
-	kind := actual.GetObjectKind().GroupVersionKind().Kind
-	logrus.Infof("Deleting object: %s, name: %s", kind, key.Name)
+	logrus.Infof("Deleting object: %s, name: %s", getObjectType(objectMeta), key.Name)
 
 	return doDelete(client, actual)
 }
@@ -280,11 +308,7 @@ func doDelete(client client.Client, actual runtime.Object) (bool, error) {
 
 func doUpdate(client client.Client, object runtime.Object) (bool, error) {
 	err := client.Update(context.TODO(), object)
-	if err == nil {
-		return true, nil
-	} else {
-		return false, err
-	}
+	return false, err
 }
 
 func doGet(client client.Client, key client.ObjectKey, object runtime.Object) (bool, error) {
@@ -299,7 +323,7 @@ func doGet(client client.Client, key client.ObjectKey, object runtime.Object) (b
 }
 
 func isUpdateUsingDeleteCreate(kind string) bool {
-	return "Service" == kind || "Ingress" == kind || "Route" == kind
+	return "Service" == kind || "Ingress" == kind || "Route" == kind || "Job" == kind || "Secret" == kind
 }
 
 func setOwnerReferenceIfNeeded(deployContext *DeployContext, blueprint metav1.Object) error {
@@ -322,3 +346,12 @@ func getClientForObject(objectNamespace string, deployContext *DeployContext) cl
 	}
 	return deployContext.ClusterAPI.NonCachedClient
 }
+
+func getObjectType(objectMeta metav1.Object) string {
+	objType := reflect.TypeOf(objectMeta).String()
+	if reflect.TypeOf(objectMeta).Kind().String() == "ptr" {
+		objType = objType[1:]
+	}
+
+	return objType
+}
